@@ -419,7 +419,8 @@ class Argilla:
             workspace = self.get_workspace()
             if not workspace:  # Just for backward comp. with datasets with no workspaces
                 workspace = "-"
-            rprint(f"{processed} records logged to {self._client.base_url}/datasets/{workspace}/{name}")
+            url = f"{self._client.base_url}/datasets/{workspace}/{name}"
+            rprint(f"{processed} records logged to [link={url}]{url}[/link]")
 
         # Creating a composite BulkResponse with the total processed and failed
         return BulkResponse(dataset=name, processed=processed, failed=failed)
@@ -512,48 +513,16 @@ class Argilla:
                 "If you want a pandas DataFrame do `rg.load('my_dataset').to_pandas()`.",
             )
 
-        try:
-            return self._load_records_new_fashion(
-                name=name,
-                query=query,
-                vector=vector,
-                ids=ids,
-                limit=limit,
-                sort=sort,
-                id_from=id_from,
-                batch_size=batch_size,
-            )
-        except ApiCompatibilityError as err:  # Api backward compatibility
-            from argilla import __version__ as version
-
-            warnings.warn(
-                message=(
-                    f"Using python client argilla=={version},"
-                    f" however deployed server version is {err.api_version}."
-                    " This might lead to compatibility issues.\n"
-                    f" Preferably, update your server version to {version}"
-                    " or downgrade your Python API at the loss"
-                    " of functionality and robustness via\n"
-                    f"`pip install argilla=={err.api_version}`"
-                ),
-                category=UserWarning,
-            )
-            if batch_size is not None:
-                warnings.warn(
-                    message="The `batch_size` parameter is not supported"
-                    f" on server version {err.api_version}. Consider"
-                    f" updating your server version to {version} to"
-                    " take advantage of this functionality."
-                )
-
-            return self._load_records_old_fashion(
-                name=name,
-                query=query,
-                ids=ids,
-                limit=limit,
-                sort=sort,
-                id_from=id_from,
-            )
+        return self._load_records_internal(
+            name=name,
+            query=query,
+            vector=vector,
+            ids=ids,
+            limit=limit,
+            sort=sort,
+            id_from=id_from,
+            batch_size=batch_size,
+        )
 
     def dataset_metrics(self, name: str) -> List[MetricInfo]:
         response = datasets_api.get_dataset(self._client, name)
@@ -647,63 +616,7 @@ class Argilla:
 
         return LabelingRuleMetricsSummary.parse_obj(response.parsed)
 
-    def _load_records_old_fashion(
-        self,
-        name: str,
-        query: Optional[str] = None,
-        ids: Optional[List[Union[str, int]]] = None,
-        limit: Optional[int] = None,
-        id_from: Optional[str] = None,
-    ) -> Dataset:
-        from argilla.client.sdk.text2text import api as text2text_api
-        from argilla.client.sdk.text2text.models import Text2TextQuery
-        from argilla.client.sdk.text_classification import (
-            api as text_classification_api,
-        )
-        from argilla.client.sdk.token_classification import (
-            api as token_classification_api,
-        )
-
-        response = datasets_api.get_dataset(client=self._client, name=name)
-        task = response.parsed.task
-
-        task_config = {
-            TaskType.text_classification: (
-                text_classification_api.data,
-                TextClassificationQuery,
-                DatasetForTextClassification,
-            ),
-            TaskType.token_classification: (
-                token_classification_api.data,
-                TokenClassificationQuery,
-                DatasetForTokenClassification,
-            ),
-            TaskType.text2text: (
-                text2text_api.data,
-                Text2TextQuery,
-                DatasetForText2Text,
-            ),
-        }
-
-        try:
-            get_dataset_data, request_class, dataset_class = task_config[task]
-        except KeyError:
-            raise ValueError(
-                f"Load method not supported for the '{task}' task. Supported tasks: "
-                f"{[TaskType.text_classification, TaskType.token_classification, TaskType.text2text]}"
-            )
-        response = get_dataset_data(
-            client=self._client,
-            name=name,
-            request=request_class(ids=ids, query_text=query),
-            limit=limit,
-            id_from=id_from,
-        )
-
-        records = [sdk_record.to_client() for sdk_record in response.parsed]
-        return dataset_class(records)
-
-    def _load_records_new_fashion(
+    def _load_records_internal(
         self,
         name: str,
         query: Optional[str] = None,
@@ -718,18 +631,9 @@ class Argilla:
         task = dataset.task
 
         task_config = {
-            TaskType.text_classification: (
-                SdkTextClassificationRecord,
-                DatasetForTextClassification,
-            ),
-            TaskType.token_classification: (
-                SdkTokenClassificationRecord,
-                DatasetForTokenClassification,
-            ),
-            TaskType.text2text: (
-                SdkText2TextRecord,
-                DatasetForText2Text,
-            ),
+            TaskType.text_classification: (SdkTextClassificationRecord, DatasetForTextClassification),
+            TaskType.token_classification: (SdkTokenClassificationRecord, DatasetForTokenClassification),
+            TaskType.text2text: (SdkText2TextRecord, DatasetForText2Text),
         }
 
         try:
@@ -744,10 +648,7 @@ class Argilla:
             if sort is not None:
                 _LOGGER.warning("Results are sorted by vector similarity, so 'sort' parameter is ignored.")
 
-            vector_search = VectorSearch(
-                name=vector[0],
-                value=vector[1],
-            )
+            vector_search = VectorSearch(name=vector[0], value=vector[1])
             results = self.search.search_records(
                 name=name,
                 task=task,
@@ -756,6 +657,7 @@ class Argilla:
                 query_text=query,
                 vector=vector_search,
             )
+
             return dataset_class(results.records)
 
         records = self.datasets.scan(
