@@ -29,15 +29,10 @@ class MetricSummary(BaseModel):
         try:
             return self._build_visualization()
         except ModuleNotFoundError:
-            warnings.warn(
-                "Please, install plotly in order to use this feature\n"
-                "%>pip install plotly"
-            )
+            warnings.warn("Please, install plotly in order to use this feature\n" "%>pip install plotly")
 
     @classmethod
-    def new_summary(
-        cls, data: Dict[str, Any], visualization: Callable
-    ) -> "MetricSummary":
+    def new_summary(cls, data: Dict[str, Any], visualization: Callable) -> "MetricSummary":
         summary = cls(data=data)
         summary._build_visualization = visualization
         return summary
