@@ -62,18 +62,17 @@ class IClientAdapter(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def list_index_documents(
+    def scan_docs(
         self,
         index: str,
-        query: Optional[BaseQuery] = None,
+        query: BaseQuery,
+        sort: SortConfig,
         size: Optional[int] = None,
         fetch_once: bool = False,
-        id_from: Optional[str] = None,
+        search_from_params: Optional[Any] = None,
         enable_highlight: bool = False,
-        sort: Optional[SortConfig] = None,
         include_fields: Optional[List[str]] = None,
         exclude_fields: Optional[List[str]] = None,
-        shuffle: bool = False,
     ) -> Iterable[Dict[str, Any]]:
         pass
 
@@ -214,6 +213,26 @@ class IClientAdapter(metaclass=ABCMeta):
     ):
         pass
 
+    @abstractmethod
+    def is_read_only_index(self, index: str) -> bool:
+        pass
+
+    @abstractmethod
+    def enable_read_only_index(self, index: str):
+        pass
+
+    @abstractmethod
+    def disable_read_only_index(self, index: str):
+        pass
+
+    @abstractmethod
+    def set_index_settings(
+        self,
+        index: str,
+        settings: Dict[str, Any],
+    ):
+        pass
+
     @abstractmethod
     def set_index_mappings(
         self,
