@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 import dataclasses
-from typing import Any, Dict, List, Optional, Type
+from typing import List, Optional, Type
 
 from fastapi import Depends
 
@@ -37,7 +37,6 @@ class DeleteRecordsOut:
 
 
 class RecordsStorageService:
-
     _INSTANCE: "RecordsStorageService" = None
 
     @classmethod
@@ -95,13 +94,11 @@ class RecordsStorageService:
         else:
             if not user.is_superuser() and user.username != dataset.created_by:
                 raise ForbiddenOperationError(
-                    f"You don't have the necessary permissions to delete records on this dataset. "
+                    "You don't have the necessary permissions to delete records on this dataset. "
                     "Only dataset creators or administrators can delete datasets"
                 )
 
-            processed, deleted = await self.__dao__.delete_records_by_query(
-                dataset, query=query
-            )
+            processed, deleted = await self.__dao__.delete_records_by_query(dataset, query=query)
 
         return DeleteRecordsOut(
             processed=processed or 0,
@@ -115,7 +112,6 @@ class RecordsStorageService:
         record: ServiceRecord,
         **data,
     ) -> ServiceRecord:
-
         if data.get("metadata"):
             record.metadata = {
                 **(record.metadata or {}),
